b'

# Risk-Reducing Effects of Arimidex for High-Risk Postmenopausal Women Last Years After Treatment Stops

Postmenopausal women at high risk for breast cancer who hadn't been diagnosed continued to get risk-reducing benefits for at least 11 years after they stopped taking Arimidex preventively.
Dec 19, 2019.
\xc2\xa0
Advertisement
Advertisement
Postmenopausal women at high risk for breast cancer who hadn\xe2\x80\x99t been diagnosed continued to get risk-reducing benefits for at least 11 years after they stopped taking Arimidex (chemical name: anastrozole) preventively, according to the latest results from the International Breast Cancer Intervention Study II (IBIS-II) study.
\n
Advertisement
The results were presented on Dec. 12, 2019, at the 2019 San Antonio Breast Cancer Symposium by Jack Cuzick, director of the Wolfson Institute for Preventive Medicine and head of the Center for Cancer Prevention at the Queen Mary University of London, where he holds the title of John Snow Professor of Epidemiology.
\n
Advertisement
Read the abstract of \xe2\x80\x9cTen year results of the international breast cancer intervention study II.\xe2\x80\x9d
\n
Advertisement
Listen to a Breastcancer.org podcast with Jack Cuzick discussing the study results.
\n
\xc2\xa0

## About Arimidex

\n
Advertisement
Arimidex is an aromatase inhibitor, a type of hormonal therapy medicine used to treat hormone-receptor-positive breast cancer and to help reduce the risk of the cancer coming back (recurrence) in postmenopausal women.
\n
Advertisement
Aromatase inhibitors work by stopping the body from producing estrogen, which limits the amount of estrogen available to stimulate hormone-receptor-positive breast cancer cells to grow.
\n
Advertisement
Other hormonal therapy medicines, including Aromasin (chemical name: exemestane), tamoxifen, and Evista (chemical name: raloxifene), have been shown to reduce the risk of developing hormone-receptor-positive breast cancer in high-risk women who haven\xe2\x80\x99t been diagnosed. So, researchers wanted to know if Arimidex could be used in the same way.
\n
\xc2\xa0

## About the IBIS-II study

\n
Advertisement
The IBIS-II study included 3,864 women considered to be at high risk of developing breast cancer. The women were considered to be at high risk because they had:
\n

\n
- a strong family history of breast cancer
\n
- been diagnosed with benign (non-cancerous) breast disease, such as lobular carcinoma in situ
\n
- dense breasts
\n

Advertisement
\n
Advertisement
None of the women in the study took hormone replacement therapy.
\n
Advertisement
Half the women were randomly assigned to take Arimidex for 5 years, and the other half were assigned to take a placebo (a dummy pill that looked just like Arimidex).
\n
Advertisement
Overall, 74.6% of the women taking Arimidex and 77% of the women taking the placebo took the medicine for the full 5 years.
\n
Advertisement
In 2013, the researchers reported results with about 7 years of follow-up, showing that women who took Arimidex were 53% less likely to develop breast cancer than women who didn\xe2\x80\x99t take Arimidex.
\n
Advertisement
The results reported at the 2019 San Antonio Breast Cancer Symposium have a median follow-up of 10.9 years, which means half the women were followed for less than 10.9 years and half the women were followed for longer periods of time.
\n
Advertisement
The new results show that women who took Arimidex were 50% less likely to be diagnosed with breast cancer than women who didn\xe2\x80\x99t take Arimidex.
\n
Advertisement
\xe2\x80\x9cThe 50% reduction in likelihood of breast cancer incidence after 10.9 years of follow-up is slightly less than the 53% reduction we reported after the first 7 years of follow-up, but it is still a significant effect and larger than that seen for tamoxifen,\xe2\x80\x9d said Cuzick. \xe2\x80\x9cAnother way to consider the result is that it translates into an estimated 29 women needing to be treated with anastrozole for 5 years to prevent one breast cancer during treatment and in the next 5 years.
\n
Advertisement
\xe2\x80\x9cThis is far fewer women than the estimated 49 women that need to be treated with tamoxifen for 5 years to prevent one breast cancer in the same time period,\xe2\x80\x9d Cuzick continued. \xe2\x80\x9cTherefore, our new results strongly suggest that anastrozole should be the preferred therapy for breast cancer prevention in postmenopausal women at increased risk for the disease, with tamoxifen used for women who experience severe side effects from anastrozole. It is exciting to see that anastrozole has a continued impact on breast cancer incidence even after stopping treatment, as this strengthens the case for its use as a breast cancer prevention therapy.\xe2\x80\x9d
\n
Advertisement
Cuzick emphasized that the protective benefits of Arimidex are only for hormone-receptor-positive breast cancer and DCIS, not for hormone-receptor-negative disease.
\n
\xc2\xa0

## Side effects

\n
Advertisement
In the IBIS-II study, about 75% of the women in each treatment group took the medicine for the full 5 years. This rate is similar to other studies that have found about 25% of women don\xe2\x80\x99t complete the full 5-year course of hormonal therapy, mainly because of side effects.
\n
Advertisement
Common side effects of Arimidex include:
\n

\n
- bone and joint pain
\n
- nausea
\n
- vomiting
\n
- hot flashes
\n
- weakness
\n
- fatigue
\n

Advertisement
\n
Advertisement
Because Arimidex lowers the amount of estrogen in the body, less estrogen reaches bone cells, which can lead to bone thinning and weakening and a higher-than-average risk of broken bones.
\n
Advertisement
In the IBIS-II study, researchers measured the women\xe2\x80\x99s bone density before the study started and any woman who had low bone density was prescribed a bisphosphonate, a type of medicine used to prevent or treat osteoporosis. Zometa (chemical name: zoledronic acid) and Boniva (chemical name: ibandronate) are two common bisphosphonates.
\n
Advertisement
For the 2019 results, Cuzick reported that there were no new side effects beyond those reported in 2013, which were muscle aches and pains and hot flashes.
\n
Advertisement
\xe2\x80\x9cNo excess of fractures or other serious side effects were seen with anastrozole,\xe2\x80\x9d he said.
\n
\xc2\xa0

## What this means for you

\n
Advertisement
If you have a higher-than-average risk of breast cancer, it makes sense to do everything you can to keep your risk as low as it can be. There are lifestyle choices you can make, including:
\n

\n
- maintaining a healthy weight
\n
- exercising regularly at the highest intensity possible
\n
- limiting or avoiding alcohol
\n
- limiting processed foods and foods high in sugar
\n
- eating healthy, nutrient-dense food
\n
- not smoking
\n

Advertisement
\n
Advertisement
You and your doctor also may be considering medicine to reduce your risk. Talk to your doctor about your preferences as well as the risks and benefits of each medicine. Together, you can make the best choice for your unique situation.
\n
Advertisement
For more information on medicines used to reduce the risk of hormone-receptor-positive breast cancer, visit the Breastcancer.org Hormonal Therapy pages.
\n
Advertisement
To talk with others who are at higher-than-average risk for breast cancer, join the Breastcancer.org Discussion Board forum High Risk for Breast Cancer.
\n
Advertisement
Written by: Jamie DePolo, senior editor
\n
Advertisement
Reviewed by: Brian Wojciechowski, M.D., medical adviser

\xe2\x80\x94 Last updated on February 22, 2022, 10:06 PM

Share your feedback
Help us learn how we can improve our research news coverage.
Was this article helpful?
advertisement
'